@@ -2,7 +2,13 @@ package Document::AST;
 
 sub new {
     my $class = shift;
-    return bless { output => [], @_ }, ref($class) || $class;
+    my $self = bless { @_ }, ref($class) || $class;
+}
+
+sub init {
+    my $self = shift;
+    die "You need to override Document::AST::insert";
+    # $self->{output} = [];
 }
 
 sub content {
@@ -13,21 +19,21 @@ sub content {
 sub insert {
     my $self = shift;
     my $ast = shift;
-    die;
+    die "You need to override Document::AST::insert";
     # $self->{output} .= $ast->{output};
 }
 
 sub begin_node {
     my $self = shift;
     my $tag = shift;
-    die;
+    die "You need to override Document::AST::begin_node";
     # $self->{output} .= "+$tag\n";
 }
 
 sub end_node {
     my $self = shift;
     my $tag = shift;
-    die;
+    die "You need to override Document::AST::end_node";
     # $self->{output} .= "-$tag\n";
 }
 
